Encode an image into a JPEG 2000 code stream
@param codec compressor handle
Creates a J2K/JP2 compression structure
@param format Coder to select
@param stream the JPEG 2000 stream.
@return Returns a handle to a compressor if successful,
returns nullptr otherwise
End to compress the current image.
@param codec Compressor handle
Set up the compressor parameters using the current image and user parameters.
Set compressing parameters to default values, that means :
Start compressing current image.
Compress uncompressed data stored in a buffer.
This method should be called right after grk_compress_start,
and before grk_end_compress.
Encode an image into a JPEG 2000 code stream using plugin
@param codec compressor handle
@param tile plugin tile
Decompress image from a JPEG 2000 code stream
Create J2K/JP2 decompression structure
End decompression
Get decompressed composite image
Get decompressed tile image
Set up the decompressor with decompress parameters
Decompress JPEG 2000 header
Initialize decompress parameters with default values
Set the given area to be decompressed. This function should be called
right after grk_decompress_read_header is called, and before any tile header is read.
Decompress a specific tile
De-initialize library
Dump codec information to file
Deallocate all component data for an image
Create image
Deallocate data for single image component
Initialize library
Increment ref count
Batch compress with plugin
Batch decompress
Release plugin resources
Compress with plugin
Decompress with plugin
Get debug state of plugin
Initialize plugin
Initialize batch decompress
Check if batch job is complete
Load plugin
Stop batch compress
Stop batch decompress
Set the MCT matrix to use.
Set error handler
Set info handler
Set warning handler
Create stream from a file identified with its filename with a specific buffer size
Create mapped file stream
Create stream from buffer
Get length of memory stream
Create an abstract stream. This function does nothing except
allocate memory and initialize abstract stream.
Set the given function to be used as a read function.
Set the given function to be used as a seek function, the stream is then seekable.
Set the given data to be used as a user data for the stream.
Set the length of the user data for the stream.
Set the given function to be used as a write function.
library version